@@ -28,47 +28,6 @@ tf.keras.backend.set_floatx('float32')
 from tensorflow import keras
 from tensorflow.keras import layers
 from tensorflow.python.training import py_checkpoint_reader
-import pip
-
-def force_install(package, versions=None):
-
-    """install one package with versions """
-
-    if versions is not None:
-        pip.main(['install', package+'=='+versions])
-    else:
-        pip.main(['install', package])
-
-def check_and_install_tfp(package, versions=None):
-
-    """make sure tfp is compatiable with tf """
-
-    try:
-        __import__(package)
-    except ImportError:
-        force_install(package, versions)
-    import tensorflow_probability as tfp
-    tfp_version=tfp.__version__.split(".")
-    if tfp_version[0:2] != versions.split(".")[0:2]:
-        force_install(package, versions)
-    #print(tfp_version[0:2], versions.split(".")[0:2])
-
-tf_version=tf.__version__.split(".")
-#print(tf_version)
-if tf_version[0] == '2' and tf_version[1] == '8': check_and_install_tfp('tensorflow_probability', '0.16.0')
-if tf_version[0] == '2' and tf_version[1] == '7': check_and_install_tfp('tensorflow_probability', '0.15.0')
-if tf_version[0] == '2' and tf_version[1] == '6': check_and_install_tfp('tensorflow_probability', '0.14.0')
-if tf_version[0] == '2' and tf_version[1] == '5': check_and_install_tfp('tensorflow_probability', '0.13.0')
-if tf_version[0] == '2' and tf_version[1] == '4': check_and_install_tfp('tensorflow_probability', '0.12.0')
-if tf_version[0] == '2' and tf_version[1] == '3': check_and_install_tfp('tensorflow_probability', '0.11.0')
-if tf_version[0] == '2' and tf_version[1] == '2': check_and_install_tfp('tensorflow_probability', '0.10.0')
-#try:
-#    __import__('tensorflow_probability')
-#except ImportError:
-#    pip.main(['install', 'package'])
-
-
-
 import tensorflow_probability as tfp
 # tf.logging.set_verbosity(tf.logging.ERROR)
 
@@ -76,28 +35,6 @@ from mechanoChemML.src.nn_models import BNN_user_weak_pde_general
 import mechanoChemML.src.pde_layers as pde_layers
 from mechanoChemML.workflows.pde_solver.pde_utility import plot_PDE_solutions, plot_fields, split_data, expand_dataset, exe_cmd, BatchData, plot_one_field_hist, plot_one_field_stat, plot_one_field,plot_PDE_solutions_new
 
-print('host:', socket.gethostname())
-if socket.gethostname() == 'Destiny':
-    physical_devices = tf.config.list_physical_devices('GPU')
-    try:
-      tf.config.experimental.set_memory_growth(physical_devices[0], True)
-    except:
-      # Invalid device or cannot modify virtual devices once initialized.
-      pass
-elif socket.gethostname().find('gpu-cn') >= 0:
-    physical_devices = tf.config.list_physical_devices('GPU')
-    try:
-      tf.config.experimental.set_memory_growth(physical_devices[0], True)
-    except:
-      # Invalid device or cannot modify virtual devices once initialized.
-      pass
-    os.environ['TF_FORCE_GPU_ALLOW_GROWTH'] = 'true'
-    print('all devices: ', physical_devices)
-    print("dynamic memory growth host", physical_devices)
-else:
-    physical_devices = tf.config.list_physical_devices('GPU')
-    print('all devices: ', physical_devices)
-    print("no dynamic memory growth")
 
 class PDEWorkflowSteadyState:
     """
@@ -162,7 +99,11 @@ class PDEWorkflowSteadyState:
         self.data_path = self.config['NN']['DataPath']
         self.NNOptimizer = self.config['NN']['Optimizer']
         self.LR0 = float(self.config['NN']['LearningRate'])
-        self.NeumannFirst = int(self.config['NN']['NeumannFirst'])
+
+        try:
+            self.NeumannFirst = int(self.config['NN']['NeumannFirst'])
+        except:
+            self.NeumannFirst = 0
 
         try:
             self.FixLoc = int(self.config['NN']['FixLoc'])
